@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014-2016, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -28,7 +28,7 @@
 // CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
-// ************************************************************************* 
+// *************************************************************************
 //
 // app/dbrowser-init.js
 //
@@ -61,10 +61,9 @@ define ([
                         entries.ePemail, entries.ePremark],
             'hook': coreLib.holdObject,
             'miniMenu': {
-                entries: ['ldapSync', 'masqEmployee'],
-                back: ['Back', 'mainEmpl']
+                entries: ['ldapSync', 'empProfileEdit', 'masqEmployee']
             }
-        }); // target.push('simpleEmployeeBrowser'
+        });
 
         target.push('simpleScheduleBrowser', {
             'name': 'simpleScheduleBrowser',
@@ -80,11 +79,10 @@ define ([
                         coreLib.emptyLineEntry, entries.ePremark],
             'hook': coreLib.holdObject,
             'miniMenu': {
-                entries: ['schedEditFromBrowser', 'schedDeleteFromBrowser'],
-                back: ['Back', 'mainSched']
+                entries: ['schedEditFromBrowser', 'schedDeleteFromBrowser']
             }
-        }); // target.push('simpleScheduleBrowser'
+        });
 
-    }; // return function ()
+    };
     
 });
