@@ -56,8 +56,11 @@ define ([
     target
 ) {
 
-    var 
-        ldapEmployeeObject = Object.create(prototypes.ldapEmpObject),
+    var ldapEmployeeObject,
+
+        resetLdapEmployeeObject = function () {
+            ldapEmployeeObject = Object.create(prototypes.ldapEmpObject);
+        },
 
         getLdapEmployeeObject = function () { return ldapEmployeeObject; },
 
@@ -141,10 +144,11 @@ define ([
                             count = rs.length;
         
                         console.log("Search found " + count + " employees");
-                        stack.push('simpleEmployeeBrowser', {
-                            'set': rs,
-                            'pos': 0
-                        });
+                        stack.push(
+                            "simpleEmployeeBrowser",
+                            {"set": rs, "pos": 0},
+                            {"flag": true},
+                        );
                     } else {
                         coreLib.displayError("Unexpected status code " + st.code);
                     }
@@ -169,7 +173,7 @@ define ([
             currentEmployeeStashed = null;
             $('#userbox').html(appLib.fillUserBox()); // reset userbox
             $('#mainarea').css("background-color", backgroundColorStashed);
-            $('#result').html('Masquerade is finished');
+            coreLib.displayResult('Masquerade is finished');
             $('input[name="sel"]').val('');
         },
         masqEmp = function (obj) {
@@ -186,7 +190,7 @@ define ([
 
             if (! coreLib.isObjEmpty(obj)) {
                 if (obj.nick === cu.nick) {
-                    $('#result').html('Request to masquerade as self makes no sense');
+                    coreLib.displayResult('Request to masquerade as self makes no sense');
                     return;
                 }
                 // let the masquerade begin
@@ -206,8 +210,8 @@ define ([
             });
         },
 
-        ldapLookupSubmit = function () {
-            var emp = stack.getState();
+        ldapLookupSubmit = function (obj) {
+            var emp = obj;
             console.log("Entering function ldapLookupSubmit, object", emp);
             // "nick" is the only property of emp that is populated
             if (! emp.nick) {
@@ -221,7 +225,9 @@ define ([
                 // success callback -- employee already exists
                 sc = function (st) {
                     if (st.code === 'DOCHAZKA_LDAP_LOOKUP') {
-                        console.log("Payload is", st.payload);
+                        console.log("Employee exists in LDAP");
+                        console.log("Server said", st);
+                        resetLdapEmployeeObject();
                         $.extend(ldapEmployeeObject, st.payload);
                     }
                     ldapEmployeeLink();
@@ -235,6 +241,20 @@ define ([
             coreLib.ajaxMessage();
         },
 
+        displayLdapEmployee = function (emp, xtarget) {
+            // The user might cause the LDAP employee to be displayed 
+            // several times in a row, e.g. by selecting LDAP sync from
+            // ldapDisplayEmployee - make sure we don't push duplicate
+            // ldapDisplayEmployee targets onto the stack!
+            var topTarget = stack.getTarget().name;
+            console.log("In displayLdapEmployee, topTarget is " + topTarget);
+            if (topTarget === 'ldapDisplayEmployee') {
+                stack.popWithoutStart();
+            }
+            stack.push('ldapDisplayEmployee', emp);
+            stack.setXTarget(xtarget);
+        },
+
         ldapEmployeeLink = function () {
             // we assume the ldapEmployeeObject has already been 
             // partially populated - we just need to determine whether
@@ -255,13 +275,13 @@ define ([
                     }
                     if (document.getElementById('ldapLookup') ||
                         document.getElementById('ldapDisplayEmployee')) {
-                        target.pull('ldapDisplayEmployee').start(ldapEmployeeObject);
+                        displayLdapEmployee(ldapEmployeeObject, 'ldapLookup');
                     }
                 },
                 fc = function (st) {
                     if (document.getElementById('ldapLookup') ||
                         document.getElementById('ldapDisplayEmployee')) {
-                        target.pull('ldapDisplayEmployee').start(ldapEmployeeObject);
+                        displayLdapEmployee(ldapEmployeeObject, 'ldapLookup');
                     }
                 }
             ajax(rest, sc, fc);
@@ -306,11 +326,11 @@ define ([
                         var obj = coreLib.dbrowserState.set[coreLib.dbrowserState.pos];
                         $.extend(coreLib.dbrowserState.obj, ldapEmployeeObject);
                         $.extend(obj, ldapEmployeeObject);
-                        start.dbrowserListen();
+                        start.dbrowserListen("Employee profile updated from LDAP");
                     }
                     if (document.getElementById('empProfile')) {
                         console.log("empProfile DOM element is present");
-                        $("#result").html("Employee profile updated from LDAP");
+                        coreLib.displayResult("Employee profile updated from LDAP");
                         stack.unwindToFlag(); // return to most recent dmenu
                     }
                 },
@@ -332,7 +352,8 @@ define ([
 
         empProfileEditSave = function (emp) {
             var protoEmp = Object.create(prototypes.empProfile),
-                employeeProfile;
+                employeeProfile,
+                parentTarget;
             console.log("Entering empProfileEditSave with object", emp);
             $.extend(protoEmp, emp);
             var rest = {
@@ -341,14 +362,31 @@ define ([
                     "body": protoEmp.sanitize()
                 },
                 sc = function (st) {
-                    // st stands for "status", i.e. AJAX return value/object
-                    console.log("Saved new employee object to database: ", protoEmp);
+                    console.log("POST employee/nick returned status", st);
+                    // what we do now depends on what targets are on the stack
+                    // the target on the top of the stack will be "empProfileEdit"
+                    // but the one below that can be either "empProfile" or
+                    // "simpleEmployeeBrowser"
+                    parentTarget = stack.getTarget(-1);
+                    console.log("parentTarget", parentTarget);
                     employeeProfile = Object.create(prototypes.empProfile);
                     $.extend(employeeProfile, st.payload);
-                    console.log("Profile object is", employeeProfile);
-                    currentUser('obj', employeeProfile);
-                    stack.unwindToFlag(); // return to most recent dmenu
-                    $("#result").html("Employee profile updated");
+                    if (parentTarget.name === 'empProfile') {
+                        console.log("Profile object is", employeeProfile);
+                        currentUser('obj', employeeProfile);
+                        stack.pop(employeeProfile, {"resultLine": "Employee profile updated"});
+                    } else if (parentTarget.name === 'simpleEmployeeBrowser') {
+                        console.log("Parent target is " + parentTarget.name);
+                        console.log("current object in dbrowerState set",
+                                    coreLib.dbrowserState.set[coreLib.dbrowserState.pos]);
+                        $.extend(
+                            coreLib.dbrowserState.set[coreLib.dbrowserState.pos],
+                            employeeProfile
+                        );
+                        stack.pop(undefined, {"resultLine": "Employee profile updated"});
+                    } else {
+                        console.log("FATAL ERROR: unexpected parent target", parentTarget);
+                    }
                 },
                 fc = function (st) {
                     console.log("AJAX: " + rest["path"] + " failed with", st);
@@ -361,6 +399,7 @@ define ([
     // employee-related actions (see daction-start.js)
     return {
         getLdapEmployeeObject: getLdapEmployeeObject,
+        resetLdapEmployeeObject: resetLdapEmployeeObject,
         myProfileAction: myProfileAction,
         empProfileEditSave: empProfileEditSave,
         ldapLookupSubmit: ldapLookupSubmit,
@@ -368,7 +407,7 @@ define ([
         ldapSyncFromBrowser: ldapSyncFromBrowser,
         actionEmplSearch: actionEmplSearch,
         endTheMasquerade: endTheMasquerade,
-        masqEmployee: masqEmp
+        masqEmployee: masqEmp,
     };
 
 });
